Crate date_filter_search
Source - DateTime
- Structure representing a custom date and time.
- DateError
- Enum representing errors related to date operations.
- TimeZoneOption
- Enum to choose the time zone.
- date_to_seconds
- Converts a ‘DateTime’ structure into the number of seconds (since ‘YEAR_START’).
- get_current_date
- Returns the current date and time using the configured time zone.
- parsing_search
- Parses the input string and determines whether to interpret it as a relative or absolute date range.
- search_generic
- Checks if a target timestamp is between ‘lower_bound’ and ‘upper_bound’ (inclusive).
- seconds_to_date
- Converts a number of seconds (since ‘YEAR_START’) into a ‘DateTime’ structure.
- set_timezone_option
- Sets the global time zone for the library.
- string_to_date_seconds
- Converts a string representing a date into the number of seconds since the epoch (‘YEAR_START’).
- validate_datetime
- Validates an input string and converts it into a ‘DateTime’ structure.